==> moodle-1.5-mysql.tgz: moodle/lang/zh_cn_utf8/editor.php <==
<?PHP // $Id$ 
      // editor.php - created with Moodle 1.5 ALPHA (2005050600)


$string['about'] = '关于此编辑器';
$string['absbottom'] = '正底部';
$string['address'] = '地址';
$string['alertnoselectedtext'] = '您必须首先选择文字!';
$string['alignment'] = '位置';
$string['alternatetext'] = '提示文本';
$string['anchorhelp'] = '这只创建一个链接点。您还需要手工创建一个超链接。';
$string['anchorname'] = '链接点名';
$string['anchors'] = '链接点';
$string['baseline'] = '基准线';
$string['bold'] = '粗体';
$string['borderthickness'] = '边框线';
$string['bottom'] = '底部';
$string['browse'] = '浏览';
$string['cancel'] = '取消';
$string['cellpadding'] = '边框';
$string['cellspacing'] = '边距';
$string['choosechar'] = '选择字符';
$string['chooseicon'] = '选择要插入的表情符';
$string['close'] = '关闭';
$string['closeafterreplace'] = '替换后关闭';
$string['cols'] = '列';
$string['copy'] = '复制所选项';
$string['createanchor'] = '创建链接点';
$string['createfolder'] = '创建文件夹';
$string['createlink'] = '插入链接';
$string['cut'] = '剪切所选项';
$string['cutpastemozilla'] = '很抱歉，你现在不能使用你所习惯的快捷键(甚至“粘贴”按钮)来粘贴文本到这个在线编辑器。这是一些版本的Mozilla和Firefox浏览器的内置安全特性引起的。<br /><br />你可以试试这三个已知的解决方法：<br /> (1) 用SHIFT+Insert来代替CTRL+v <br /> (2) 使用浏览器菜单里的Edit->Paste<br /> (3) 通过编辑user.js来改变浏览器的参数。<br /><br />点下面的“确定”键获得更多帮助，或者点“放弃”回到编辑器';
$string['delete'] = '删除';
$string['filebrowser'] = '文件浏览';
$string['findwhat'] = '查找';
$string['fontname'] = '字体名';
$string['fontsize'] = '字号';
$string['forecolor'] = '字体颜色';
$string['formatblock'] = '格式';
$string['fullscreen'] = '全屏幕编辑器';
$string['heading'] = '标题';
$string['height'] = '高度';
$string['hilitecolor'] = '背景色';
$string['horizontal'] = '水平位置';
$string['horizontalrule'] = '水平线';
$string['htmlmode'] = '切换到HTML代码模式';
$string['imageurl'] = '图片网址';
$string['indent'] = '缩进';
$string['insertchar'] = '插入特殊字符';
$string['insertimage'] = '插入图片';
$string['insertlink'] = '插入链接';
$string['insertsmile'] = '插入表情符';
$string['inserttable'] = '插入表格';
$string['italic'] = '斜体字';
$string['itemsreplaced'] = '项目被替换';
$string['justifycenter'] = '正中';
$string['justifyfull'] = '两端对齐';
$string['justifyleft'] = '正左';
$string['justifyright'] = '正右';
$string['layout'] = '版式';
$string['left'] = '左';
$string['lefttoright'] = '从左向右';
$string['linkproperties'] = '链接属性';
$string['linktarget'] = '目标';
$string['linktargetblank'] = '新窗口';
$string['linktargetnone'] = '无';
$string['linktargetother'] = '其它';
$string['linktargetself'] = '同一框架';
$string['linktargettop'] = '同一窗口';
$string['linktitle'] = '标题';
$string['linkurl'] = 'URL';
$string['matchcase'] = '匹配大小写';
$string['middle'] = '中央';
$string['minimize'] = '最小化编辑器';
$string['move'] = '移动';
$string['nolink'] = '不自动处理链接';
$string['normal'] = '常规';
$string['notimage'] = '所选文件不是图片. 请选则一张图片!';
$string['notset'] = '未设置';
$string['ok'] = '确定';
$string['options'] = '选项';
$string['orderedlist'] = '列表编号';
$string['outdent'] = '减少缩进量';
$string['paste'] = '粘贴';
$string['path'] = '路径';
$string['percent'] = '百分比';
$string['pixels'] = '象素';
$string['popupeditor'] = '在弹出的大窗口中打开编辑器';
$string['preformatted'] = '默认段落字体';
$string['preview'] = '预览';
$string['properties'] = '属性';
$string['redo'] = '重做';
$string['regularexpressions'] = '使用正则表达式';
$string['removelink'] = '删除连接';
$string['rename'] = '重命名';
$string['replaceall'] = '替换全部';
$string['replacewith'] = '替换';
$string['right'] = '右';
$string['righttoleft'] = '从右向左';
$string['rows'] = '行';
$string['searchandreplace'] = '搜索和替换';
$string['searchnotfound'] = '未找到字符串！';
$string['selectcolor'] = '选择颜色';
$string['selection'] = '选择';
$string['showhelp'] = '编辑器使用帮助';
$string['size'] = '大小';
$string['spacing'] = '位置';
$string['strikethrough'] = '删除线';
$string['subscript'] = '下标';
$string['superscript'] = '上标';
$string['textindicator'] = '当前风格';
$string['textmode'] = '现在是文本模式。点击[<>]按钮返回所见即所得模式.';
$string['texttop'] = '文字顶部';
$string['top'] = '顶部';
$string['type'] = '类别';
$string['underline'] = '下划线';
$string['undo'] = '撤销上步操作';
$string['unorderedlist'] = '项目符号';
$string['upload'] = '上传';
$string['vertical'] = '垂直位置';
$string['width'] = '宽度';
$string['wordclean'] = '净化Word HTML';
$string['zip'] = 'Zip';

?>

==> moodle-1.5.3-mysql.tgz: moodle/lang/zh_cn_utf8/editor.php <==
<?PHP // $Id$ 
      // editor.php - created with Moodle 1.5 ALPHA (2005050600)


$string['about'] = '关于此编辑器';
$string['absbottom'] = '正底部';
$string['address'] = '地址';
$string['alertnoselectedtext'] = '您必须首先选择文字!';
$string['alignment'] = '位置';
$string['alternatetext'] = '提示文本';
$string['anchorhelp'] = '这只创建一个链接点。您还需要手工创建一个超链接。';
$string['anchorname'] = '链接点名';
$string['anchors'] = '链接点';
$string['baseline'] = '基准线';
$string['bold'] = '粗体';
$string['borderthickness'] = '边框线';
$string['bottom'] = '底部';
$string['browse'] = '浏览';
$string['cancel'] = '取消';
$string['cellpadding'] = '边框';
$string['cellspacing'] = '边距';
$string['choosechar'] = '选择字符';
$string['chooseicon'] = '选择要插入的表情符';
$string['close'] = '关闭';
$string['closeafterreplace'] = '替换后关闭';
$string['cols'] = '列';
$string['copy'] = '复制所选项';
$string['createanchor'] = '创建链接点';
$string['createfolder'] = '创建文件夹';
$string['createlink'] = '插入链接';
$string['cut'] = '剪切所选项';
$string['cutpastemozilla'] = '很抱歉，您现在不能使用您所习惯的快捷键(甚至“粘贴”按钮)来粘贴文本到这个在线编辑器。这是一些版本的Mozilla和Firefox浏览器的内置安全特性引起的。<br /><br />您可以试试这三个已知的解决方法：<br /> (1) 用SHIFT+Insert来代替CTRL+v <br /> (2) 使用浏览器菜单里的Edit->Paste<br /> (3) 通过编辑user.js来改变浏览器的参数。<br /><br />点下面的“确定”键获得更多帮助，或者点“放弃”回到编辑器';
$string['delete'] = '删除';
$string['filebrowser'] = '文件浏览';
$string['findwhat'] = '查找';
$string['fontname'] = '字体名';
$string['fontsize'] = '字号';
$string['forecolor'] = '字体颜色';
$string['formatblock'] = '格式';
$string['fullscreen'] = '全屏幕编辑器';
$string['heading'] = '标题';
$string['height'] = '高度';
$string['hilitecolor'] = '背景色';
$string['horizontal'] = '水平位置';
$string['horizontalrule'] = '水平线';
$string['htmlmode'] = '切换到HTML代码模式';
$string['imageurl'] = '图片网址';
$string['indent'] = '缩进';
$string['insertchar'] = '插入特殊字符';
$string['insertimage'] = '插入图片';
$string['insertlink'] = '插入链接';
$string['insertsmile'] = '插入表情符';
$string['inserttable'] = '插入表格';
$string['italic'] = '斜体字';
$string['itemsreplaced'] = '项目被替换';
$string['justifycenter'] = '正中';
$string['justifyfull'] = '两端对齐';
$string['justifyleft'] = '正左';
$string['justifyright'] = '正右';
$string['layout'] = '版式';
$string['left'] = '左';
$string['lefttoright'] = '从左向右';
$string['linkproperties'] = '链接属性';
$string['linktarget'] = '目标';
$string['linktargetblank'] = '新窗口';
$string['linktargetnone'] = '无';
$string['linktargetother'] = '其它';
$string['linktargetself'] = '同一框架';
$string['linktargettop'] = '同一窗口';
$string['linktitle'] = '标题';
$string['linkurl'] = 'URL';
$string['matchcase'] = '匹配大小写';
$string['middle'] = '中央';
$string['minimize'] = '最小化编辑器';
$string['move'] = '移动';
$string['nolink'] = '不自动处理链接';
$string['normal'] = '常规';
$string['notimage'] = '所选文件不是图片. 请选则一张图片!';
$string['notset'] = '未设置';
$string['ok'] = '确定';
$string['options'] = '选项';
$string['orderedlist'] = '列表编号';
$string['outdent'] = '减少缩进量';
$string['paste'] = '粘贴';
$string['path'] = '路径';
$string['percent'] = '百分比';
$string['pixels'] = '象素';
$string['popupeditor'] = '在弹出的大窗口中打开编辑器';
$string['preformatted'] = '默认段落字体';
$string['preview'] = '预览';
$string['properties'] = '属性';
$string['redo'] = '重做';
$string['regularexpressions'] = '使用正则表达式';
$string['removelink'] = '删除连接';
$string['rename'] = '重命名';
$string['replaceall'] = '替换全部';
$string['replacewith'] = '替换';
$string['right'] = '右';
$string['righttoleft'] = '从右向左';
$string['rows'] = '行';
$string['searchandreplace'] = '搜索和替换';
$string['searchnotfound'] = '未找到字符串！';
$string['selectcolor'] = '选择颜色';
$string['selection'] = '选择';
$string['showhelp'] = '编辑器使用帮助';
$string['size'] = '大小';
$string['spacing'] = '位置';
$string['strikethrough'] = '删除线';
$string['subscript'] = '下标';
$string['superscript'] = '上标';
$string['textindicator'] = '当前风格';
$string['textmode'] = '现在是文本模式。点击[<>]按钮返回所见即所得模式.';
$string['texttop'] = '文字顶部';
$string['top'] = '顶部';
$string['type'] = '类别';
$string['underline'] = '下划线';
$string['undo'] = '撤销上步操作';
$string['unorderedlist'] = '项目符号';
$string['upload'] = '上传';
$string['vertical'] = '垂直位置';
$string['width'] = '宽度';
$string['wordclean'] = '净化Word HTML';
$string['zip'] = 'Zip';

?>
